@@ -17,7 +17,7 @@ ServerListView::~ServerListView()
 }
 void ServerListView::dragMoveEvent(QDragMoveEvent *e)
 {
-    QTreeWidgetItem* item = this->itemAt(e->pos());
+    QTreeWidgetItem* item = this->itemAt(e->position().toPoint());
     QTreeWidgetItem* sItem = this->currentItem();
     bool bad;
     //  bad selection || dropping on viewport must be a toplevelitem || children of the same parent (or lack thereof)
@@ -61,7 +61,7 @@ bool ServerListView::badDropSelection()
                 children.append(item);
                 parent = children.at(0)->parent();
                 // make sure all the children have the same parent
-                for (QTreeWidgetItem* child : qAsConst(children)) {
+                for (QTreeWidgetItem* child : std::as_const(children)) {
                     if (child->parent() != parent)
                         return true;
                 }
