@@ -1,14 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Wed Feb 6 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #ifndef QUICKBUTTON_H
@@ -28,13 +21,15 @@ class QuickButton : public QPushButton
         void setDefinition(const QString &newDefinition);
 
         Q_SIGNALS:
-        void clicked(int);
         void clicked(const QString &definition);
 
-    public Q_SLOTS:
+    private Q_SLOTS:
         void wasClicked();
 
-    protected:
+    private:
         QString definition;
+
+        Q_DISABLE_COPY(QuickButton)
 };
+
 #endif
